@@ -240,7 +240,7 @@ class PedidoVenda(models.Model):
     cliente = models.ForeignKey('cliente.Cliente', related_name='pedidos')
     conta = models.ForeignKey('plataforma.Conta', related_name='pedidos_vendas', on_delete=models.CASCADE)
     contrato = models.ForeignKey('plataforma.Contrato', related_name='pedidos_vendas')
-    cupom = models.ForeignKey("marketing.CupomDesconto", db_column='cupom_desconto_id', related_name='pedidos', null=True)
+    # cupom = models.ForeignKey("marketing.CupomDesconto", db_column='cupom_desconto_id', related_name='pedidos', null=True)
     envios = models.ManyToManyField('configuracao.Envio', through='PedidoVendaFormaEnvio', related_name='pedidos')
     pagamentos = models.ManyToManyField('configuracao.FormaPagamento', through='PedidoVendaFormaPagamento', related_name='pedidos')
 
@@ -401,6 +401,16 @@ class PedidoVendaItem(models.Model):
     def __unicode__(self):
         return unicode(self.id)
 
+    def reservar_item(self):
+        return PedidoVendaItemReserva.objects.create(
+            quantidade=self.quantidade,
+            pedido=self.pedido,
+            pedido_item=self,
+            produto=self.produto,
+            produto_pai=self.produto_pai,
+            conta=self.conta
+        )
+
 
 class PedidoVendaItemReserva(models.Model):
     """Itens reservados de um pedido de venda."""
